@@ -44,6 +44,10 @@ class MultiNLI(_ContinuumDataset):
             download.unzip(path)
             print("Dataset extracted.")
 
+    @property
+    def nb_classes(self):
+        return 20
+
     @property
     def data_type(self) -> TaskType:
         return TaskType.TEXT
