@@ -25,6 +25,10 @@ class PascalVOC2012(_ContinuumDataset):
         super().__init__(data_path=data_path, train=train, download=download)
         self.augmented = augmented
 
+    @property
+    def nb_classes(self):
+        return 20
+
     @property
     def data_type(self) -> TaskType:
         return TaskType.SEGMENTATION
