@@ -8,10 +8,64 @@ from continuum.scenarios import ContinualScenario, OnlineFellowship
 from continuum.tasks import TaskType
 
 
+def update_remapping(new_classes, mapping=None):
+    """
+    Output a vector of classes existing class to get new class labels do:
+     new_label = np.array(list(map(lambda x: remapping.tolist().index(x), old_label)))
+
+    :param new_classes: list of new classes
+    :param current_mapping: vector with previous remapping
+    """
+    array_new_classes = np.array(new_classes)
+    if mapping is None:
+        mapping = np.unique(array_new_classes)
+    else:
+        mapping = mapping.tolist()
+        for c in np.unique(array_new_classes):
+            if c not in mapping:
+                mapping.append(c)
+        mapping = np.array(mapping)
+
+    return mapping
+
+
+def remap_class_vector(class_vector, remapping=None):
+    """
+    From a mapping vector and a vector of classes output a vector of remapped classes with the mapping eventually updated
+
+    :param class_vector: vector of class labels to remap
+    :param remapping: 1D vector with current mapping might be None if the mapping does not exist yet
+    """
+    remapping = update_remapping(class_vector, remapping)
+    new_class_vector = np.array(list(map(lambda x: remapping.tolist().index(x), class_vector)))
+    return new_class_vector.astype(int), remapping
+
+
+def get_original_targets(targets: np.ndarray, mapping) -> np.ndarray:
+    """Returns the original targets not changed by the custom class order.
+
+    :param targets: An array of targets, as provided by the task datasets.
+    :param mapping: An array of targets,  that map old classes to new classes
+    :return: An array of targets, with their original values.
+    """
+    return mapping[targets]
+
+
+def get_scenario_remapping(scenario):
+    list_classes = []
+    [list_classes.append(taskset.get_classes()) for taskset in scenario]
+    class_order = np.concatenate(list_classes)  # mapping
+    return class_order
+
+
 def create_subscenario(base_scenario, task_indexes):
     """
     In this function we want to create a subscenario from the different tasks, either by subsampling tasks or reodering
     or both.
+
+    :param base_scenario: scenario from which the subscenario will be created
+    :param task_indexes: array with new order of tasks
+    :return: A train PyTorch's Datasets.
     """
 
     if torch.is_tensor(task_indexes):
@@ -22,6 +76,7 @@ def create_subscenario(base_scenario, task_indexes):
     else:
         transformations = base_scenario.transformations
     sub_scenario = None
+
     if isinstance(base_scenario, OnlineFellowship):
         # We just want to changes base_scenario.cl_datasets order
         new_cl_datasets = [base_scenario.cl_datasets[i] for i in task_indexes]
@@ -37,7 +92,6 @@ def create_subscenario(base_scenario, task_indexes):
         new_x, new_y, new_t = None, None, None
         if base_scenario.cl_dataset.bounding_boxes is not None:
             raise ValueError("the function create_subscenario is not compatible with scenario with bounding_boxes yet.")
-
         for i, index in enumerate(task_indexes):
             taskset = base_scenario[index]
             all_task_indexes = np.arange(len(taskset))
