@@ -3,12 +3,13 @@ import numpy as np
 import pytest
 import random
 import string
+import torch
 
 import torch.nn as nn
 
 from continuum.datasets import InMemoryDataset, MNIST
 from torchvision import transforms
-from continuum.scenarios import ClassIncremental, create_subscenario, encode_scenario
+from continuum.scenarios import ClassIncremental, create_subscenario, encode_scenario, remap_class_vector, get_scenario_remapping
 from continuum.tasks import TaskType
 
 DATA_PATH = os.environ.get("CONTINUUM_DATA_PATH")
@@ -42,6 +43,54 @@ def gen_string():
     return x_train, y_train
 
 
+def test_classes_remapping():
+    mapping = None
+    y_0 = np.random.randint(low=0, high=10, size=100)
+    remap_y_0, mapping = remap_class_vector(y_0, mapping)
+    assert len(np.unique(y_0)) == max(remap_y_0) + 1
+    y_1 = np.random.randint(low=15, high=20, size=100)
+    remap_y_1, mapping = remap_class_vector(y_1, mapping)
+    y_2 = np.random.randint(low=90, high=100, size=100)
+    remap_y_2, mapping = remap_class_vector(y_2, mapping)
+    y_3 = np.random.randint(low=0, high=10, size=100)
+    remap_y_3, mapping = remap_class_vector(y_3, mapping)
+    y_4 = np.random.randint(low=0, high=45, size=100)
+    remap_y_4, mapping = remap_class_vector(y_4, mapping)
+
+    # check that remapping did not change
+    assert np.equal(remap_class_vector(y_0, mapping)[0], remap_y_0).all()
+
+    full_vector = np.concatenate([y_0, y_1, y_2, y_3, y_4], axis=0)
+    assert np.equal(np.unique(remap_class_vector(full_vector)[0]), np.arange(len(mapping))).all()
+    assert len(np.unique(full_vector)) <= len(mapping)
+
+def test_classes_remapping2():
+
+    y_0 = np.random.randint(low=0, high=10, size=100)
+    remap_y_0, mapping = remap_class_vector(y_0, remapping=None)
+    y_1 = np.random.randint(low=15, high=20, size=100)
+    remap_y_1, mapping = remap_class_vector(y_1, mapping)
+
+    assert np.equal(remap_class_vector(y_0, mapping)[0], remap_y_0).all()
+
+def test_scenario_remapping():
+    list_tasks = np.arange(9, -1, -1)
+    x_train, y_train, t_train = gen_data()
+    dummy = InMemoryDataset(x_train, y_train, t_train, data_type=TaskType.IMAGE_PATH)
+    scenario = ClassIncremental(dummy, increment=1)
+    subscenario = create_subscenario(scenario, list_tasks)
+
+    mapping = get_scenario_remapping(subscenario)
+    np_classes = np.zeros(0)
+    np_classes_remapped = np.zeros(0).astype(int)
+    for taskset in subscenario:
+        np_classes = np.concatenate([np_classes, taskset.get_classes()], axis=0)
+        np_classes_remapped = np.concatenate([np_classes_remapped, remap_class_vector(taskset.get_classes(), mapping)[0]], axis=0)
+    nb_classes_seen = len(np_classes)
+
+    assert np.equal(np_classes_remapped, np.arange(nb_classes_seen)).all()
+    assert not np.equal(np_classes, np.arange(nb_classes_seen)).all()
+
 @pytest.mark.parametrize("list_tasks", [
     np.arange(10),
     np.arange(5, 10),
@@ -81,6 +130,7 @@ def test_sequence_transforms(list_tasks):
     subscenario = create_subscenario(scenario, list_tasks)
     assert subscenario.nb_tasks == len(list_tasks), print(f"{len(subscenario)} - vs - {len(list_tasks)}")
 
+
 @pytest.mark.parametrize("list_tasks", [
     np.arange(10),
     np.arange(5, 10),
@@ -94,12 +144,16 @@ def test_slicing_list_path_array(list_tasks):
     subscenario = create_subscenario(scenario, list_tasks)
     assert subscenario.nb_tasks == len(list_tasks), print(f"{len(subscenario)} - vs - {len(list_tasks)}")
 
-
 def test_encode_scenario():
     filename_h5 = "test_encode_scenario.hdf5"
     if os.path.exists(filename_h5):
         os.remove(filename_h5)
 
+    if torch.cuda.is_available():
+        inference_fct = (lambda model, x: model.to(torch.device('cuda:0'))(x.to(torch.device('cuda:0'))))
+    else:
+        inference_fct = (lambda model, x: model(x))
+
     train = gen_data()
     x, y, t = train
     x = x.reshape(-1, 32 * 32 * 3)
@@ -111,7 +165,8 @@ def test_encode_scenario():
     encoded_scenario = encode_scenario(model=model,
                                        scenario=scenario,
                                        batch_size=64,
-                                       filename=filename_h5)
+                                       filename=filename_h5,
+                                       inference_fct=inference_fct)
 
     assert scenario.nb_tasks == encoded_scenario.nb_tasks
     assert len(scenario[0]) == len(encoded_scenario[0])
